/*
 * @brief This header file is part of Ding RTC engine sdk for iOS/Mac system
 *
 * @copyright Copyright (c) 2024, Alibaba Inc.
 * All rights reserved
 */

#import <DingRTC/DingRtcEngineTypes.h>

NS_ASSUME_NONNULL_BEGIN

/**
* @defgroup OC_DingRtcWhiteboardDef 关键类型定义
* DingRtc 关键类型定义
*/

/**
 * @ingroup OC_DingRtcWhiteboardDef
 *
 * @since 3.6
 * @brief 白板模式。
 */
typedef NS_ENUM(NSUInteger, DingRtcWbMode) {
    /** 基础模式。 */
    DingRtcWbModeBasic     = 0,
    /** 高级模式。 */
    DingRtcWbModeAdvance = 1,
};

/**
 * @ingroup OC_DingRtcWhiteboardDef
 *
 * @since 3.6
 * @brief 白板配置参数。
 */
__attribute__((visibility("default"))) @interface DingRtcWbConfig : NSObject

/** 白板模式。 */
@property (nonatomic, assign) DingRtcWbMode mode;
/** 白板宽度。 */
@property (nonatomic, assign) NSUInteger width;
/** 白板高度。 */
@property (nonatomic, assign) NSUInteger height;

@end

/**
 * @ingroup OC_DingRtcWhiteboardDef
 *
 * @since 3.6
 * @brief 标注类型。
 */
typedef NS_ENUM(NSUInteger, DingRtcAnnoType) {
    /** 共享标注。 */
    DingRtcAnnoTypeShare      = 0,
    /** 视频标注。 */
    DingRtcAnnoTypeVideo      = 1,
    /** 外部标注。 */
    DingRtcAnnoTypeExternal   = 2,
};

/**
 * @ingroup OC_DingRtcWhiteboardDef
 *
 * @since 3.6
 * @brief 标注配置参数。
 */
__attribute__((visibility("default"))) @interface DingRtcAnnoConfig : NSObject

/** 标注类型。 */
@property (nonatomic, assign) DingRtcAnnoType type;

@end

/**
 * @ingroup OC_DingRtcWhiteboardDef
 * @since 3.5
 * @brief 白板用户成员。
 *
 */
__attribute__((visibility("default"))) @interface DingRtcWbUserMember : NSObject

@property (nonatomic, copy) NSString *uid;

@end

/**
 * @ingroup OC_DingRtcWhiteboardDef
 *
 * @since 3.6
 * @brief 白板角色类型。
 */
typedef NS_ENUM(NSUInteger, DingRtcWbRoleType) {
    /** 白板管理员。 */
    DingRtcWbRoleTypeAdmin      = 0,
    /** 普通白板参与者。 */
    DingRtcWbRoleTypeAttendee   = 1,
    /** 只看白板参与者。 */
    DingRtcWbRoleTypeViewer     = 2,
};

/**
 * @ingroup OC_DingRtcWhiteboardDef
 *
 * @since 3.6
 * @brief 白板工具参数。
 */
typedef NS_ENUM(NSUInteger, DingRtcWbTool) {
    /** 空。 */
    DingRtcWbToolNone           = 0,
    /** 选中。 */
    DingRtcWbToolSelect         = 1,
    /** 点击。 */
    DingRtcWbToolClick          = 2,
    /** 拖拽。 */
    DingRtcWbToolHand           = 3,
    /** 画笔。 */
    DingRtcWbToolPath           = 4,
    /** 直线。 */
    DingRtcWbToolLine           = 5,
    /** 矩形。 */
    DingRtcWbToolRect           = 6,
    /** 椭圆。 */
    DingRtcWbToolEllipse        = 7,
    /** 图片。 */
    DingRtcWbToolImage          = 8,
    /** 文本。 */
    DingRtcWbToolText           = 9,
    /** 删除工具。 */
    DingRtcWbToolDeleter        = 10,
    /** 刷子。 */
    DingRtcWbToolBrush          = 11,
    /** 箭头。 */
    DingRtcWbToolArrow          = 12,
    /** 折线。 (仅适用于 Mac 系统) */
    DingRtcWbToolPolyline       = 13,
    /** 弧线。 (仅适用于 Mac 系统) */
    DingRtcWbToolArc            = 15,
    /** 曲线。 (仅适用于 Mac 系统) */
    DingRtcWbToolCurve          = 16,
    /** 激光笔。 */
    DingRtcWbToolLaser          = 17,
    /** 图章。 */
    DingRtcWbToolStamp          = 18,
    /** 消失笔。 */
    DingRtcWbToolVanishPen      = 19,
    /** 荧光笔。 */
    DingRtcWbToolHighlighter    = 20,
    /** 橡皮擦。 */
    DingRtcWbToolEraser         = 21,
};

/**
 * @ingroup OC_DingRtcWhiteboardDef
 *
 * @since 3.6
 * @brief 白板填充类型。
 */
typedef NS_ENUM(NSUInteger, DingRtcWbFillType) {
    /** 不填充。 */
    DingRtcWbFillTypeNone           = 0,
    /** 填充颜色。 */
    DingRtcWbFillTypeColor          = 1,
    /** 边框并填充。 */
    DingRtcWbFillTypeBorderFill     = 2,
};

/**
 * @ingroup OC_DingRtcWhiteboardDef
 *
 * @since 3.6
 * @brief 白板颜色。
 */
__attribute__((visibility("default"))) @interface DingRtcWbColor : NSObject

/** 红色成分，有效值范围：[0.0, 1.0]。默认值：0.0。 */
@property (nonatomic, assign) float r;
/** 绿色成分，有效值范围：[0.0, 1.0]。默认值：0.0。 */
@property (nonatomic, assign) float g;
/** 蓝色成分，有效值范围：[0.0, 1.0]。默认值：0.0。 */
@property (nonatomic, assign) float b;
/** 透明度成分，有效值范围：[0.0, 1.0]。默认值：1.0。 */
@property (nonatomic, assign) float a;

@end

/**
 * @ingroup OC_DingRtcWhiteboardDef
 *
 * @since 3.6
 * @brief 白板字体样式。
 */
typedef NS_ENUM(NSUInteger, DingRtcWbFontStyle) {
    /** 常规。 */
    DingRtcWbFontStyleNormal        = 0,
    /** 粗体。 */
    DingRtcWbFontStyleBold          = 1,
    /** 斜体。 */
    DingRtcWbFontStyleItalic        = 2,
    /** 粗斜体。 */
    DingRtcWbFontStyleBoldItalic    = 3,
};

/**
 * @ingroup OC_DingRtcWhiteboardDef
 *
 * @since 3.6
 * @brief 白板文本格式。
 */
__attribute__((visibility("default"))) @interface DingRtcWbTextFormat : NSObject

/** 字体大小，有效值范围：[10, 96]。默认值：12。 */
@property (nonatomic, assign) NSUInteger size;
/** 字体样式 */
@property (nonatomic, assign) DingRtcWbFontStyle style;
/** 字体颜色 */
@property (nonatomic, strong) DingRtcWbColor* color;

@end

/**
 * @ingroup OC_DingRtcWhiteboardDef
 *
 * @since 3.6
 * @brief 白板渲染缩放模式。
 */
typedef NS_ENUM(NSUInteger, DingRtcWbScalingMode) {
    /** 保持宽高比 */
    DingRtcWbScalingModeFit         = 0,
    /** 保持宽高比全填充 */
    DingRtcWbScalingModeCropFill    = 1,
    /** 原始大小居中显示 */
    DingRtcWbScalingModeCenterCrop  = 2,
    /** 拉伸铺满全填充 */
    DingRtcWbScalingModeStretchFill = 3,
};

/**
 * @ingroup OC_DingRtcWhiteboardDef
 *
 * @since 3.6
 * @brief 白板渲染缩放基准。
 */
typedef NS_ENUM(NSUInteger, DingRtcWbScalingBaseType) {
    /** 默认。100%对应原始白板大小。 */
    DingRtcWbScalingBaseTypeDefault = 0,
    /** 视图基准。100%对应FIT填充视图。 */
    DingRtcWbScalingBaseTypeView    = 1,
};

/**
 * @ingroup OC_DingRtcWhiteboardDef
 *
 * @since 3.6
 * @brief 白板清除模式。
 */
typedef NS_ENUM(NSUInteger, DingRtcWbClearMode) {
    /** 全部内容。 */
    DingRtcWbClearModeAll       = 0,
    /** 其它人内容。 */
    DingRtcWbClearModeOthers    = 1,
    /** 自己内容。 */
    DingRtcWbClearModeSelf      = 2,
    /** 指定内容。 */
    DingRtcWbClearModeSpecific  = 3,
};

/**
 * @ingroup OC_DingRtcWhiteboardDef
 *
 * @since 3.6
 * @brief 白板清除配置。
 */
__attribute__((visibility("default"))) @interface DingRtcWbClearParam : NSObject

/** 是否仅清除当前页，默认为YES。 */
@property (nonatomic, assign) BOOL curPage;
/** 白板清除模式 */
@property (nonatomic, assign) DingRtcWbClearMode mode;

@end

/**
 * @ingroup OC_DingRtcWhiteboardDef
 *
 * @since 3.6
 * @brief 绘制事件类型。
 */
typedef NS_ENUM(NSUInteger, DingRtcWbDrawEvent) {
    /** 未知事件。 */
    DingRtcWbDrawEventUnknow            = 0,
    /** 绘制开始。 */
    DingRtcWbDrawEventStart             = 1,
    /** 绘制结束。 */
    DingRtcWbDrawEventEnd               = 2,
    /** 绘制取消。 */
    DingRtcWbDrawEventCancel            = 3,
    /** 选择移动开始。 */
    DingRtcWbDrawEventSelectMoveStart   = 4,
    /** 指定内容。 */
    DingRtcWbDrawEventSelectMoveEnd     = 5,
    /** 指定内容。 */
    DingRtcWbDrawEventDeleteStart       = 6,
    /** 指定内容。 */
    DingRtcWbDrawEventDeleteEnd         = 7,
    /** 指定内容。 */
    DingRtcWbDrawEventTextDraw          = 8,
    /** 指定内容。 */
    DingRtcWbDrawEventTextUpdate        = 9,
};

/**
 * @ingroup OC_DingRtcWhiteboardDef
 *
 * @since 3.6
 * @brief 内容更新类型。
 */
typedef NS_ENUM(NSUInteger, DingRtcWbContentUpdateType) {
    /** 未知。 */
    DingRtcWbContentUpdateTypeUnkonw        = 0,
    /** 远端绘制。 */
    DingRtcWbContentUpdateTypeRemoteDraw    = 1,
};

/**
 * @ingroup OC_DingRtcWhiteboardDef
 *
 * @since 3.6
 * @brief 快照模式。
 */
typedef NS_ENUM(NSUInteger, DingRtcWbSnapshotMode) {
    /** 视图显示区域。 */
    DingRtcWbSnapshotModeView   = 0,
    /** 全部区域。 */
    DingRtcWbSnapshotModeAll    = 1,
};

/**
 * @ingroup OC_DingRtcWhiteboardDef
 *
 * @since 3.6
 * @brief 白板文档类型。
 */
typedef NS_ENUM(NSUInteger, DingRtcWbDocType) {
    /** 普通。 */
    DingRtcWbDocTypeNormal      = 1,
    /** PDF。 */
    DingRtcWbDocTypePdf         = 3,
    /** 外部。 */
    DingRtcWbDocTypeExternal    = 5,
};

/**
 * @ingroup OC_DingRtcWhiteboardDef
 *
 * @since 3.6
 * @brief 白板文档信息。
 */
__attribute__((visibility("default"))) @interface DingRtcWbDocInfo : NSObject

/** 文档类型。 */
@property (nonatomic, assign) DingRtcWbDocType type;
/** 文档Id。 */
@property (nonatomic, copy) NSString *docId;
/** 文档名称。 */
@property (nonatomic, copy) NSString *name;
/** 文档创建人用户Id。 */
@property (nonatomic, copy) NSString *creator;

@end

/**
 * @ingroup OC_DingRtcWhiteboardDef
 *
 * @since 3.5
 * @brief 白板文档内容信息 */
__attribute__((visibility("default"))) @interface DingRtcWbDocContents : NSObject

/** 文档类型。 */
@property (nonatomic, assign) DingRtcWbDocType type;
/** 文档名称。 */
@property (nonatomic, copy) NSString *name;
/** url地址数组。 */
@property (nonatomic, copy) NSArray<NSString *> *urls;
/** 文档转码ID。 */
@property (nonatomic, copy) NSString *transDocId;

@end

/**
 * @ingroup OC_DingRtcWhiteboardDef
 *
 * @since 3.6
 * @brief 白板外部文档信息。
 */
__attribute__((visibility("default"))) @interface DingRtcWbDocExtContents : NSObject

/** 外部名称。 */
@property (nonatomic, copy) NSString *name;
/** 总页数，默认值为1。 */
@property (nonatomic, assign) NSUInteger totalPages;
/** 文档宽度 */
@property (nonatomic, assign) NSUInteger width;
/** 文档高度 */
@property (nonatomic, assign) NSUInteger height;

@end

/**
 * @ingroup OC_DingRtcWhiteboardDef
 *
 * @since 3.6
 * @brief 白板触摸配置。
 */
__attribute__((visibility("default"))) @interface DingRtcWbTouchConfig : NSObject

/** 是否开启手掌检测。 */
@property (nonatomic, assign) BOOL enable;
/** 小接触大小。 */
@property (nonatomic, assign) float smallContactSize;
/** 大接触大小。 */
@property (nonatomic, assign) float largeContactSize;
/** 小橡皮擦大小，默认值100.f。 */
@property (nonatomic, assign) float smallEraserSize;
/** 大橡皮擦大小，默认值200.f。 */
@property (nonatomic, assign) float largeEraserSize;

@end

/**
 * @ingroup OC_DingRtcWhiteboardDef
 *
 * @since 3.6
 * @brief 图章相关信息。
 */
__attribute__((visibility("default"))) @interface DingRtcWbStamp : NSObject

/** 图章资源ID。最大长度128字节 */
@property (nonatomic, copy) NSString *stampId;
/** 图章资源路径 */
@property (nonatomic, copy) NSString *path;
/** 图章是否可以改变大小。默认值：NO。 */
@property (nonatomic, assign) BOOL resizable;

@end

/**
 * @ingroup OC_DingRtcWhiteboardDef
 *
 * @since 3.6
 * @brief 白板选项。
 * @note @(BOOL) 表示，值应该是 NSNumber 类型，NSNumber中的变量值为 BOOL 类型，@(int) 和  @(float)  也是同理。
 */
typedef NS_ENUM(NSUInteger, DingRtcWbOptionType) {
    /** 启用白板响应UI事件。默认启用，type 为 @(BOOL)  */
    DingRtcWbOptionTypeEnableUIResponse         = 2,
    /** 显示或隐藏白板涂鸦。默认显示。背景图和H5内容不受此选项影响，type 为 @(BOOL) */
    DingRtcWbOptionTypeEnableShowDraws          = 3,
    /** 启用白板画布缩放移动。默认启用。SetZoomScale 不受此选项的影响，type 为 @(BOOL) */
    DingRtcWbOptionTypeEnableScaleMove          = 4,
    /** 设置图片或音视频对象默认选中状态。默认启用，type 为 @(BOOL) */
    DingRtcWbOptionTypeEnableAutoSelected       = 5,
    /** 启用光标位置同步。默认关闭，type 为 @(BOOL) */
    DingRtcWbOptionTypeEnableCursorPosSync      = 6,
    /** 开启显示远端光标。默认关闭，type 为 @(BOOL) */
    DingRtcWbOptionTypeEnableShowRemoteCursor   = 7,
    /** 是否显示本地用户名称。默认关闭，type 为 @(BOOL) */
    DingRtcWbOptionTypeEnableLocalCursorLabel   = 9,
    /** 选中时是否显示对象用户名称。默认打开，type 为 @(BOOL) */
    DingRtcWbOptionTypeEnableSelectShowName     = 10,
    /** 打开触屏模式。默认关闭，type 为 @(BOOL) */
    DingRtcWbOptionTypeEnableTouchScreen        = 11,
    /** 打开激光笔尾巴。默认打开，type 为 @(BOOL) */
    DingRtcWbOptionTypeEnableLaserTrail         = 12,
    /** 打开橡皮擦轨迹。默认关闭，type 为 @(BOOL) */
    DingRtcWbOptionTypeEnableEraseTrail         = 13,
    /** 设置选择和删除热区大小。默认值10.f，type 为 @(float) */
    DingRtcWbOptionTypeHotZoneSize              = 15,
    /** 设置触摸点光标大小。默认值32，type 为 @(int) */
    DingRtcWbOptionTypeCursorSize               = 16,
    /** 开启手掌橡皮擦。默认关闭，type 为 @(BOOL) */
    DingRtcWbOptionTypeEnablePalmEraser         = 17,
    /** 设置橡皮擦热区大小。默认值100.f，type 为 @(float) */
    DingRtcWbOptionTypeEraserZoneSize           = 18,
    /** 触摸配置。默认关闭，type 为 DingRtcWbTouchConfig */
    DingRtcWbOptionTypeTouchConfig              = 19,
};

/**
 * @ingroup OC_DingRtcWhiteboardDef
 *
 * @since 3.6
 * @brief 标注选项。
 * @note @(BOOL) 表示，值应该是 NSNumber 类型，NSNumber中的变量值为 BOOL 类型，@(int) 和  @(float)  也是同理。
 */
typedef NS_ENUM(NSUInteger, DingRtcAnnoOptionType) {
    /** 启用本地标注渲染。默认启用，该选项需要在调用open前设置，type 为 @(BOOL)  */
    DingRtcAnnoOptionTypeEnableLocalRender        = 1,
    /** 显示或隐藏标注涂鸦。默认显示，type 为 @(BOOL) */
    DingRtcAnnoOptionTypeEnableShowDraws          = 2,
    /** 启用标注响应UI事件。默认启用，type 为 @(BOOL) */
    DingRtcAnnoOptionTypeEnableUIResponse         = 3,
    /** 启用标注画布缩放移动。默认启用，SetZoomScale 不受此选项的影响，type 为 @(BOOL) */
    DingRtcAnnoOptionTypeEnableScaleMove          = 4,
    /** 启用光标位置同步。默认关闭，type 为 @(BOOL) */
    DingRtcAnnoOptionTypeEnableCursorPosSync      = 5,
    /** 开启显示远端光标。默认关闭，type 为 @(BOOL) */
    DingRtcAnnoOptionTypeEnableShowRemoteCursor   = 6,
    /** 缩放基准模式。type 为 DingRtcWbScalingBaseType */
    DingRtcAnnoOptionTypeEnableScaleBaseMode      = 8,
    /** 是否显示本地用户名称。默认关闭，type 为 @(BOOL) */
    DingRtcAnnoOptionTypeEnableLocalCursorLabel   = 9,
    /** 是否自动跟踪窗口大小和位置。默认开启，如关闭需依赖setWindowPos设置，type 为 @(BOOL) */
    DingRtcAnnoOptionTypeAutoTrackingWindow       = 10,
    /** 选中时是否显示对象用户名称。默认打开，type 为 @(BOOL) */
    DingRtcAnnoOptionTypeEnableSelectShowName     = 11,
    /** 打开触屏模式。默认关闭，type 为 @(BOOL) */
    DingRtcAnnoOptionTypeEnableTouchScreen        = 12,
    /** 打开激光笔尾巴。默认打开，type 为 @(BOOL) */
    DingRtcAnnoOptionTypeEnableLaserTrail         = 13,
    /** 打开橡皮擦轨迹。默认关闭，type 为 @(BOOL) */
    DingRtcAnnoOptionTypeEnableEraseTrail         = 14,
    /** 本地绘制开启低刷新率。默认关闭，仅对低渲染性能设备设置，type 为 @(BOOL) */
    DingRtcAnnoOptionTypeLocalLowRefreshRate      = 15,
    /** 设置选择和删除热区大小。默认值10.f，type 为 @(float) */
    DingRtcAnnoOptionTypeHotZoneSize              = 17,
    /** 设置触摸点光标大小。默认值32，type 为 @(int) */
    DingRtcAnnoOptionTypeCursorSize               = 18,
    /** 设置橡皮擦热区大小。默认值100.f，type 为 @(float) */
    DingRtcAnnoOptionTypeEraserZoneSize           = 19,
};

/**
 * @ingroup OC_DingRtcWhiteboardDef
 *
 * @since 3.6
 * @brief 白板图像状态。
 */
typedef NS_ENUM(NSUInteger, DingRtcWbImageState) {
    /** 开始加载图片。 */
    DingRtcWbImageStateLoadStart      = 0,
    /** 加载图片成功。 */
    DingRtcWbImageStateLoadComplete   = 1,
    /** 加载图片失败。 */
    DingRtcWbImageStateLoadFail   = 2,
};

/**
 * @ingroup OC_DingRtcWhiteboardDef
 *
 * @since 3.6
 * @brief 文件转码状态。
 */
typedef NS_ENUM(NSUInteger, DingRtcWbFileTransState) {
    /** 开启转码。 */
    DingRtcWbFileTransStateTranscodeStart       = 0,
    /** 转码成功。 */
    DingRtcWbFileTransStateTranscodeComplete    = 1,
    /** 转码失败。 */
    DingRtcWbFileTransStateTranscodeFail        = 2,
    /** 转码开启失败。 */
    DingRtcWbFileTransStateTranscodeStartFail   = 3,
    /** 转码查询失败。 */
    DingRtcWbFileTransStateTranscodeQueryFail   = 4,
};

NS_ASSUME_NONNULL_END
